import { useState } from 'react';
import { IconButton, Tooltip } from '@mui/material';
import { Slideshow } from '@mui/icons-material';
import { Screensaver } from './Screensaver';
import { useAutoScreensaver } from '../hooks/useAutoScreensaver';

export function ScreensaverButton() {
  const [manualScreensaverOpen, setManualScreensaverOpen] = useState(false);
  const { isActive: autoScreensaverActive, resetTimer } = useAutoScreensaver(5); // 5 minutes

  const handleOpenScreensaver = () => {
    console.log('ScreensaverButton: Opening manual screensaver');
    setManualScreensaverOpen(true);
  };

  const handleCloseScreensaver = () => {
    console.log('ScreensaverButton: Closing screensaver');
    setManualScreensaverOpen(false);
    resetTimer(); // Reset the auto-screensaver timer when manually closed
  };

  const isScreensaverOpen = manualScreensaverOpen || autoScreensaverActive;

  console.log('ScreensaverButton: Rendering, screensaverOpen =', isScreensaverOpen, 'autoActive =', autoScreensaverActive);

  return (
    <>
      <Tooltip title="Launch screensaver">
        <IconButton onClick={handleOpenScreensaver}>
          <Slideshow />
        </IconButton>
      </Tooltip>
      {isScreensaverOpen && (
        <Screensaver onClose={handleCloseScreensaver} />
      )}
    </>
  );
}