import { CommandBuilder } from '../printer-commands';
import { TestCommandExecutor } from '../command-executor';
import { BARCODE_CONFIG } from '../printer-constants';

describe('Barcode Debug', () => {
  let commandExecutor: TestCommandExecutor;

  beforeEach(() => {
    commandExecutor = new TestCommandExecutor();
  });

  it('should test different barcode formats', async () => {
    const testData = '123456789';

    // Test basic barcode
    const commands = [
      CommandBuilder.text('Testing barcode:'),
      CommandBuilder.barcode(testData),
      CommandBuilder.newline(),
    ];

    await commandExecutor.executeCommands(commands);
    const output = commandExecutor.getOutput();

    console.log('Barcode test output:', output);
    expect(output).toContain('[BARCODE: 123456789]');
  });

  it('should test task barcode', async () => {
    const taskId = 123;

    const commands = [
      CommandBuilder.text('Testing task barcode:'),
      CommandBuilder.taskBarcode(taskId),
      CommandBuilder.newline(),
    ];

    await commandExecutor.executeCommands(commands);
    const output = commandExecutor.getOutput();

    console.log('Task barcode test output:', output);
    expect(output).toContain('[BARCODE: 100000123]');
  });

  it('should test step barcode', async () => {
    const stepId = 456;

    const commands = [
      CommandBuilder.text('Testing step barcode:'),
      CommandBuilder.stepBarcode(stepId),
      CommandBuilder.newline(),
    ];

    await commandExecutor.executeCommands(commands);
    const output = commandExecutor.getOutput();

    console.log('Step barcode test output:', output);
    expect(output).toContain('[BARCODE: 200000456]');
  });

  it('should test barcode with alignment', async () => {
    const testData = '987654321';

    const commands = [
      CommandBuilder.text('Testing barcode with alignment:'),
      ...CommandBuilder.barcodeWithAlignment(testData),
      CommandBuilder.newline(),
    ];

    await commandExecutor.executeCommands(commands);
    const output = commandExecutor.getOutput();

    console.log('Barcode with alignment test output:', output);
    expect(output).toContain('[BARCODE: 987654321]');
  });

  it('should test task barcode with alignment', async () => {
    const taskId = 789;

    const commands = [
      CommandBuilder.text('Testing task barcode with alignment:'),
      ...CommandBuilder.taskBarcodeWithAlignment(taskId),
      CommandBuilder.newline(),
    ];

    await commandExecutor.executeCommands(commands);
    const output = commandExecutor.getOutput();

    console.log('Task barcode with alignment test output:', output);
    expect(output).toContain('[BARCODE: 100000789]');
  });

  it('should test barcode configuration', () => {
    console.log('Barcode config:', BARCODE_CONFIG);
    expect(BARCODE_CONFIG.TYPE).toBe('CODE39');
    expect(BARCODE_CONFIG.ALTERNATIVE_TYPES).toContain('CODE128');
  });
});