import { formatUtils } from '../format-utils';
import { Command } from '../printer-commands';

describe('formatUtils', () => {
  it('banner returns a BANNER command', () => {
    expect(formatUtils.banner('=', 10)).toEqual([Command.BANNER, '=', 10]);
  });

  it('checkbox returns a CHECKBOX command', () => {
    expect(formatUtils.checkbox('Test')).toEqual([Command.CHECKBOX, 'Test']);
  });

  it('list returns a LIST command', () => {
    expect(formatUtils.list(['A', 'B'], 1, '- ')).toEqual([[Command.LIST, ['A', 'B'], 1, '- ']]);
  });

  it('stepHeader returns a CHECKBOX command with formatted text', () => {
    expect(formatUtils.stepHeader('StepName', 2, 'TaskName', true)).toEqual([Command.CHECKBOX, 'Step 2: StepName']);
    expect(formatUtils.stepHeader('StepName', 2, 'TaskName', false)).toEqual([Command.CHECKBOX, 'Step 2 of TaskName: StepName']);
  });

  it('section returns a list of commands', () => {
    expect(formatUtils.section('Header', 'Content')).toEqual([
      [Command.CHECKBOX, 'Header'],
      [Command.BANNER, '='],
      [Command.TEXT, 'Content'],
    ]);
    expect(formatUtils.section('Header', 'Content', '-', true)).toEqual([
      [Command.CHECKBOX, 'Header'],
      [Command.BANNER, '-'],
      [Command.TEXT, 'Content'],
      [Command.NEWLINE],
    ]);
  });

  it('getCheckboxText extracts text from a CHECKBOX command', () => {
    expect(formatUtils.getCheckboxText([Command.CHECKBOX, 'Hello'])).toBe('Hello');
    expect(formatUtils.getCheckboxText([Command.BANNER, '='])).toBe('');
  });

  it('taskHeader returns a CHECKBOX command for the task', () => {
    expect(formatUtils.taskHeader('My Task')).toEqual([Command.CHECKBOX, 'Task: My Task']);
  });

  it('taskSection returns a list of commands for the task section', () => {
    expect(formatUtils.taskSection('My Task')).toEqual([
      [Command.CHECKBOX, 'Task: My Task'],
      [Command.BANNER, '='],
    ]);
  });
});