import { PAPER_CONFIG } from "./printer-constants";
import { Command, CommandTuple } from './printer-commands';

export const formatUtils = {
  /**
   * Creates a banner command
   */
  banner(char: string, length: number = PAPER_CONFIG.BANNER_LENGTH): CommandTuple {
    return [Command.BANNER, char, length];
  },

  /**
   * Creates a banner string (repeated character)
   */
  bannerString(char: string, length: number = PAPER_CONFIG.BANNER_LENGTH): string {
    return char.repeat(length);
  },

  /**
   * Checkbox command
   */
  checkbox(text: string): CommandTuple {
    return [Command.CHECKBOX, text];
  },

  /**
   * List of items as commands
   */
  list(items: string[], startIndex: number = 0, prefix: string = ''): CommandTuple[] {
    return [[Command.LIST, items, startIndex, prefix]];
  },

  /**
   * Step header as a command
   */
  stepHeader(stepName: string, stepNumber: number, taskName?: string, isTaskView: boolean = false): CommandTuple {
    const parts = ['Step'];
    if (stepNumber !== undefined) {
      parts.push(' ');
      parts.push(stepNumber.toString());
    }
    if (!isTaskView && taskName) {
      parts.push(` of ${taskName}`);
    }
    parts.push(': ');
    parts.push(stepName);
    return [Command.CHECKBOX, parts.join('')];
  },

  /**
   * Section as a list of commands
   */
  section(header: string, content: string, bannerChar: string = '=', trailingNewline: boolean = false): CommandTuple[] {
    const commands: CommandTuple[] = [
      [Command.CHECKBOX, header],
      [Command.BANNER, bannerChar],
      [Command.TEXT, content],
    ];
    if (trailingNewline) {
      commands.push([Command.NEWLINE]);
    }
    return commands;
  },

  /**
   * Extracts the text from a CHECKBOX CommandTuple
   */
  getCheckboxText(cmd: CommandTuple): string {
    if (cmd[0] === Command.CHECKBOX && typeof cmd[1] === 'string') {
      return cmd[1];
    }
    return '';
  },

  /**
   * Task header as a command
   */
  taskHeader(taskName: string): CommandTuple {
    return [Command.CHECKBOX, `Task: ${taskName}`];
  },

  /**
   * Task section as a list of commands
   */
  taskSection(taskName: string): CommandTuple[] {
    return [
      [Command.CHECKBOX, `Task: ${taskName}`],
      [Command.BANNER, '='],
    ];
  },
};