import { Knex } from 'knex';
import { Printer, Task, Step } from '@shared/index';
import { TaskRepository, StepRepository, PrintHistoryRepository } from '../db/repositories';

export async function printTask(
  taskId: number,
  userId: number,
  db: Knex,
  printer: Printer
): Promise<Task> {
  const taskRepo = new TaskRepository(db);
  const printHistoryRepo = new PrintHistoryRepository(db);

  const task = await taskRepo.findById(taskId);
  if (!task) throw new Error('Task not found');

  await printer.printTask(task, db);
  await printHistoryRepo.create({
    user_id: userId,
    task_id: taskId,
    printed_at: new Date(),
  });

  await taskRepo.update(taskId, {
    print_count: (task.print_count || 0) + 1,
    last_printed_at: new Date(),
  });

  const updatedTask = await taskRepo.findById(taskId);
  if (!updatedTask) throw new Error('Task not found after update');
  return updatedTask;
}

export async function printStep(
  stepId: number,
  userId: number,
  db: Knex,
  printer: Printer
): Promise<Step> {
  const stepRepo = new StepRepository(db);
  const printHistoryRepo = new PrintHistoryRepository(db);

  const step = await stepRepo.findById(stepId);
  if (!step) throw new Error('Step not found');

  await printer.printStep(step, db);
  await printHistoryRepo.create({
    user_id: userId,
    step_id: stepId,
    printed_at: new Date(),
  });

  await stepRepo.update(stepId, {
    print_count: (step.print_count || 0) + 1,
    last_printed_at: new Date(),
  });

  const updatedStep = await stepRepo.findById(stepId);
  if (!updatedStep) throw new Error('Step not found after update');
  return updatedStep;
}